@@ -45,6 +45,7 @@ defaults = {
     'log_file' : 'dexy.log',
     'log_format' : "%(name)s - %(levelname)s - %(message)s",
     'log_level' : "INFO",
+    'output_root' : '.',
     'pickle' : 'c',
     'plugins': '',
     'profile' : False,
@@ -306,3 +307,19 @@ def char_diff(str1, str2):
     # TODO add code for str2 longer than str1
 
     return msg
+
+# http://code.activestate.com/recipes/576874-levenshtein-distance/
+def levenshtein(s1, s2):
+    l1 = len(s1)
+    l2 = len(s2)
+
+    matrix = [range(l1 + 1)] * (l2 + 1)
+    for zz in range(l2 + 1):
+      matrix[zz] = range(zz,zz + l1 + 1)
+    for zz in range(0,l2):
+      for sz in range(0,l1):
+        if s1[sz] == s2[zz]:
+          matrix[zz+1][sz+1] = min(matrix[zz+1][sz] + 1, matrix[zz][sz+1] + 1, matrix[zz][sz])
+        else:
+          matrix[zz+1][sz+1] = min(matrix[zz+1][sz] + 1, matrix[zz][sz+1] + 1, matrix[zz][sz] + 1)
+    return matrix[l2][l1]
